@@ -385,6 +385,19 @@ END
          'perl -MCPAN -e \'CPAN::Shell->notest('.
          '"install","HTTP::Server::Simple")\'',
          '__display__');
+   }
+      $show=<<END;
+########################################
+
+   INSTALLING Perl::Critic
+
+########################################
+END
+      print $show;
+      cmd_raw($handle,
+         'perl -MCPAN -e \'CPAN::Shell->notest('.
+         '"install","Perl::Critic")\'',
+         '__display__');
    }
    my $show=<<END;
 ########################################
@@ -502,7 +515,7 @@ END
                \__/_     ___ __ _| |_ __ _| |_   _ ___| |_
                /    \   / __/ _` | __/ _` | | | | / __| __|  Perl MVC
             _- |    |  | (_| (_| | || (_| | | |_| \__ \ |    framework
-       _ _-'   \____/   \___\__,_|\__\__,_|_|\__, |___/\__|©
+       _ _-'   \____/   \___\__,_|\__\__,_|_|\__, |___/\__|c
      ((_)       ---\                         |___/
                     \
                      \\_          Web Framework
@@ -1536,10 +1549,10 @@ print "GOING TO START WEB SERVER\n";
           | \ | | ___| |_      |  ___|   _| | |  / \  _   _| |_  |
           |  \| |/ _ \ __| o o | |_ | | | | | | / _ \| | | | __/ | \
           | |\  |  __/ |_  o o |  _|| |_| | | |/ ___ \ |_| | ||     |
-          |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
+          |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ (C)
 
 
-   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright (C) 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
@@ -1662,11 +1675,11 @@ our $select_chaining_setup=sub {
                      _    ___     _ _   _       _                     
                    ((_)  | __|  _| | | /_\ _  _| |_  |                   
                     /    | _| || | | |/ _ \ || |  _/ | \   Automates     _
-                   /     |_| \_,_|_|_/_/ \_\_,_|\__\___/©  Everything  _| |_ 
+                   /     |_| \_,_|_|_/_/ \_\_,_|\__\___/c  Everything  _| |_ 
                \__/_     ___ __ _| |_ __ _| |_   _ ___| |_            |_   _|
                /    \   / __/ _` | __/ _` | | | | / __| __|  Perl MVC   |_|
             _- |    |  | (_| (_| | || (_| | | |_| \__ \ |    framework
-       _ _-'   \____/   \___\__,_|\__\__,_|_|\__, |___/\__|©
+       _ _-'   \____/   \___\__,_|\__\__,_|_|\__, |___/\__|c
      ((_)       ---\                         |___/
                     \
                      \\_   Web Framework & SSH Proxy Chaining via RESTful
